@@ -186,7 +186,7 @@ class Movie(object):
         self.progress.set_data(parent_window, _("Fetching data"), _("Wait a moment"), False)
         retriever = Retriever(url_to_fetch, self.parent_window, self.progress, useurllib2=self.useurllib2)
         retriever.start()
-        while retriever.isAlive():
+        while retriever.is_alive():
             self.progress.pulse()
             if self.progress.status:
                 retriever.join()
@@ -222,7 +222,7 @@ class Movie(object):
                 self.progress.set_data(self.parent_window, _("Fetching poster"), _("Wait a moment"), False)
                 retriever = Retriever(self.image_url, self.parent_window, self.progress, dest, useurllib2=self.useurllib2)
                 retriever.start()
-                while retriever.isAlive():
+                while retriever.is_alive():
                     self.progress.pulse()
                     if self.progress.status:
                         retriever.join()
@@ -356,7 +356,7 @@ class SearchMovie(object):
         else:
             retriever = Retriever(url, parent_window, self.progress, destination, useurllib2=self.useurllib2)
         retriever.start()
-        while retriever.isAlive():
+        while retriever.is_alive():
             self.progress.pulse()
             if self.progress.status:
                 retriever.join()
